@@ -11,7 +11,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Port::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.442';
+$VERSION = '3.444';
 
 structs('_new_base',
 	'Verilog::Netlist::Port::Struct'
@@ -143,8 +143,8 @@ See also Verilog::Netlist::Subclass for additional accessors and methods.
 Any array declaration for the port.  This only applies to Verilog 1995
 style ports which can declare port bits independently from the signal
 declarations.  When using Verilog 2001 style ports, see the matching net
-declaration's lsb and msb methods instead, for example
-C<$module->find_net($port->name)->msb>.
+declaration's data_type, msb and lsb methods instead, for example
+C<$module->find_net($port->name)->data_type>.
 
 =item $self->comment
 
